;; Generated package description from nftables-mode.el  -*- no-byte-compile: t -*-
(define-package "nftables-mode" "1.1" "Major mode for editing nftables" '((emacs "25.1")) :commit "05600129ee8ea0774c6ac446a2bd18fc1dde54eb" :url "https://elpa.gnu.org/packages/nftables-mode.html" :authors '(("Trent W. Buck" . "trentbuck@gmail.com")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("convenience"))
